ExternalGlobalControllerMetrics

Struct ExternalGlobalControllerMetrics 

pub struct ExternalGlobalControllerMetrics {
Show 30 fields pub state: PipelineState, pub bootstrap_in_progress: bool, pub transaction_status: TransactionStatus, pub transaction_id: TransactionId, pub transaction_msecs: Option<u64>, pub transaction_records: Option<u64>, pub commit_progress: Option<CommitProgressSummary>, pub transaction_initiators: ExternalTransactionInitiators, pub rss_bytes: u64, pub memory_pressure: MemoryPressure, pub memory_pressure_epoch: u64, pub cpu_msecs: u64, pub uptime_msecs: u64, pub start_time: DateTime<Utc>, pub incarnation_uuid: Uuid, pub initial_start_time: DateTime<Utc>, pub storage_bytes: u64, pub storage_mb_secs: u64, pub runtime_elapsed_msecs: u64, pub buffered_input_records: u64, pub buffered_input_bytes: u64, pub total_input_records: u64, pub total_input_bytes: u64, pub total_processed_records: u64, pub total_processed_bytes: u64, pub total_completed_records: u64, pub output_stall_msecs: u64, pub total_initiated_steps: Step, pub total_completed_steps: Step, pub pipeline_complete: bool,
}
Global controller metrics.

Fields

state: PipelineState

State of the pipeline: running, paused, or terminating.

bootstrap_in_progress: bool

The pipeline has been resumed from a checkpoint and is currently bootstrapping new and modified views.

transaction_status: TransactionStatus

Status of the current transaction.

transaction_id: TransactionId

ID of the current transaction or 0 if no transaction is in progress.

transaction_msecs: Option<u64>

Elapsed time in milliseconds, according to transaction_status:

transaction_records: Option<u64>

Number of records in this transaction, according to transaction_status:

commit_progress: Option<CommitProgressSummary>

Progress of the current transaction commit, if one is in progress.

transaction_initiators: ExternalTransactionInitiators

Entities that initiated the current transaction.

rss_bytes: u64

Resident set size of the pipeline process, in bytes.

memory_pressure: MemoryPressure

Memory pressure.

memory_pressure_epoch: u64

Memory pressure epoch.

cpu_msecs: u64

CPU time used by the pipeline across all threads, in milliseconds.

uptime_msecs: u64

Time since the pipeline process started, including time that the pipeline was running or paused.

This is the elapsed time since start_time.

start_time: DateTime<Utc>

Time at which the pipeline process started, in seconds since the epoch.

incarnation_uuid: Uuid

Uniquely identifies the pipeline process that started at start_time.

initial_start_time: DateTime<Utc>

Time at which the pipeline process from which we resumed started, in seconds since the epoch.

storage_bytes: u64

Current storage usage in bytes.

storage_mb_secs: u64

Storage usage integrated over time, in megabytes * seconds.

runtime_elapsed_msecs: u64

Time elapsed while the pipeline is executing a step, multiplied by the number of threads, in milliseconds.

buffered_input_records: u64

Total number of records currently buffered by all endpoints.

buffered_input_bytes: u64

Total number of bytes currently buffered by all endpoints.

total_input_records: u64

Total number of records received from all endpoints.

total_input_bytes: u64

Total number of bytes received from all endpoints.

total_processed_records: u64

Total number of input records processed by the DBSP engine.

total_processed_bytes: u64

Total bytes of input records processed by the DBSP engine.

total_completed_records: u64

Total number of input records processed to completion.

output_stall_msecs: u64

If the pipeline is stalled because one or more output connectors’ output buffers are full, this is the number of milliseconds that the current stall has lasted.

If this is nonzero, then the output connectors causing the stall can be identified by noticing ExternalOutputEndpointMetrics::queued_records is greater than or equal to ConnectorConfig::max_queued_records.

In the ordinary case, the pipeline is not stalled, and this value is 0.

total_initiated_steps: Step

Number of steps that have been initiated.

Interpretation

This is a count, not a step number. If total_initiated_steps is 0, no steps have been initiated. If total_initiated_steps > 0, then step total_initiated_steps - 1 has been started and all steps previous to that have been completely processed by the circuit.

total_completed_steps: Step

Number of steps whose input records have been processed to completion.

A record is processed to completion if it has been processed by the DBSP engine and all outputs derived from it have been processed by all output connectors.

Interpretation

This is a count, not a step number. If total_completed_steps is 0, no steps have been processed to completion. If total_completed_steps > 0, then the last step whose input records have been processed to completion is total_completed_steps - 1. A record that was ingested when total_initiated_steps was n is fully processed when total_completed_steps >= n.

pipeline_complete: bool

True if the pipeline has processed all input data to completion.