pub struct ExternalOutputEndpointMetrics {
pub transmitted_records: u64,
pub transmitted_bytes: u64,
pub queued_records: u64,
pub queued_batches: u64,
pub buffered_records: u64,
pub buffered_batches: u64,
pub num_encode_errors: u64,
pub num_transport_errors: u64,
pub total_processed_input_records: u64,
pub total_processed_steps: Step,
pub memory: u64,
pub batch_records_written: Option<u64>,
}Expand description
Performance metrics for an output endpoint.
Fields
transmitted_records: u64Records sent on the underlying transport.
transmitted_bytes: u64Bytes sent on the underlying transport.
queued_records: u64Number of queued records.
queued_batches: u64Number of queued batches.
buffered_records: u64Number of records pushed to the output buffer.
buffered_batches: u64Number of batches in the buffer.
num_encode_errors: u64Number of encoding errors.
num_transport_errors: u64Number of transport errors.
total_processed_input_records: u64The number of input records processed by the circuit.
This metric tracks the end-to-end progress of the pipeline: the output
of this endpoint is equal to the output of the circuit after
processing total_processed_input_records records.
In a multihost pipeline, this count reflects only the input records processed on the same host as the output endpoint, which is not usually meaningful.
total_processed_steps: StepThe number of steps whose input records have been processed by the endpoint.
This is meaningful in a multihost pipeline because steps are synchronized across all of the hosts.
Interpretation
This is a count, not a step number. If total_processed_steps is 0, no
steps have been processed to completion. If total_processed_steps > 0, then the last step whose input records have been processed to
completion is total_processed_steps - 1. A record that was ingested in
step n is fully processed when total_processed_steps > n.
memory: u64Extra memory in use beyond that used for queuing records.
batch_records_written: Option<u64>Number of records written so far while the connector is processing a batch of updates. Resets to 0 after the batch is committed.
None when the connector does not support batch-progress reporting.