pub struct CheckpointMetadata {
pub uuid: Uuid,
pub identifier: Option<String>,
pub fingerprint: u64,
pub size: Option<u64>,
pub steps: Option<u64>,
pub processed_records: Option<u64>,
}Expand description
Holds meta-data about a checkpoint that was taken for persistent storage and recovery of a circuit’s state.
Fields
uuid: UuidA unique identifier for the given checkpoint.
This is used to identify the checkpoint in the file-system hierarchy.
identifier: Option<String>An optional name for the checkpoint.
fingerprint: u64Fingerprint of the circuit at the time of the checkpoint.
size: Option<u64>Total size of the checkpoint files in bytes.
steps: Option<u64>Total number of steps made.
processed_records: Option<u64>Total number of records processed.