pub struct PSpineBatches {
pub files: Vec<String>,
}Expand description
Format of pspine-batches-*.dat in storage.
These files exist to be a simple format for higher-level code and outside tools to parse. The spine itself writes them for that purpose, but it does not read them.
Fields
files: Vec<String>Trait Implementations
Sourceimpl Debug for PSpineBatches
impl Debug for PSpineBatches
Sourceimpl<'de> Deserialize<'de> for PSpineBatches
impl<'de> Deserialize<'de> for PSpineBatches
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more