StorageCacheConfig

Enum StorageCacheConfig 

pub enum StorageCacheConfig {
    PageCache,
    FelderaCache,
}
How to cache access to storage within a Feldera pipeline.

Variants



PageCache

Use the operating system’s page cache as the primary storage cache.

This is the default because it currently performs better than FelderaCache.



FelderaCache

Use Feldera’s internal cache implementation.

This is under development. It will become the default when its performance exceeds that of PageCache.

Implementations