pub struct PipelineTemplateConfig {
pub name: String,
pub key: String,
}Expand description
Configuration for supplying a custom pipeline StatefulSet template via a Kubernetes ConfigMap.
Operators can provide a custom StatefulSet YAML that the Kubernetes runner will use when
creating pipeline StatefulSets for a pipeline. The custom template must be stored as the
value of a key in a ConfigMap in the same namespace as the pipeline; set name to the
ConfigMap name and key to the entry that contains the template.
Recommendations and requirements:
- Start from the default template and modify it as needed. The default template is present
in ConfigMap named as
<release-name>-pipeline-template, with keypipelineTemplatein the release namespace and should be used as a reference. - The template must contain a valid Kubernetes
StatefulSetmanifest in YAML form. The runner substitutes variables in the template before parsing; therefore the final YAML must be syntactically valid. - The runner performs simple string substitution for the following placeholders. Please ensure these
placeholders are placed at appropriate location for their semantics:
{id}: pipeline Kubernetes name (used for object names and labels){namespace}: Kubernetes namespace where the pipeline runs{pipeline_executor_image}: container image used to run the pipeline executor{binary_ref}: program binary reference passed as an argument{program_info_ref}: program info reference passed as an argument{pipeline_storage_path}: mount path for persistent pipeline storage{storage_class_name}: storage class name to use for PVCs (if applicable){deployment_id}: UUID identifying the deployment instance{deployment_initial}: initial desired runtime status (e.g.,provisioning){bootstrap_policy}: bootstrap policy value when applicable
Fields
name: StringName of the ConfigMap containing the pipeline template.
key: StringKey in the ConfigMap containing the pipeline template.
If not set, defaults to pipelineTemplate.