pub struct AvroSchemaRegistryConfig {
pub registry_urls: Vec<String>,
pub registry_headers: HashMap<String, String>,
pub registry_proxy: Option<String>,
pub registry_timeout_secs: Option<u64>,
pub registry_username: Option<String>,
pub registry_password: Option<String>,
pub registry_authorization_token: Option<String>,
}Expand description
Schema registry configuration.
Fields
registry_urls: Vec<String>List of schema registry URLs.
-
Input connector: When non-empty, the connector retrieves Avro message schemas from the registry.
-
Output connector: When non-empty, the connector will post the schema to the registry and embed the schema id returned by the registry in Avro messages. Otherwise, schema id 0 is used.
registry_headers: HashMap<String, String>Custom headers that will be added to every call to the schema registry.
This property is only applicable to output connectors.
Requires registry_urls to be set.
registry_proxy: Option<String>Proxy that will be used to access the schema registry.
Requires registry_urls to be set.
registry_timeout_secs: Option<u64>Timeout in seconds used to connect to the registry.
Requires registry_urls to be set.
registry_username: Option<String>Username used to authenticate with the registry.
Requires registry_urls to be set. This option is mutually exclusive with
token-based authentication (see registry_authorization_token).
registry_password: Option<String>Password used to authenticate with the registry.
Requires registry_urls to be set.
Token used to authenticate with the registry.
Requires registry_urls to be set. This option is mutually exclusive with
password-based authentication (see registry_username and registry_password).