Module pipeline_diff

Module pipeline_diff 

Structs

PipelineDiff
Summary of changes in the pipeline between checkpointed and new versions.
ProgramDiff
Summary of changes in the program between checkpointed and new versions.

Functions

program_diff