pub enum PipelineDiffError {
BootstrapNotAllowed {
error: String,
},
}Expand description
Error returned by compute_pipeline_diff.
Variants
BootstrapNotAllowed
The change requires bootstrapping, but bootstrapping is not allowed because the old or the new program has relations with lateness.