pub struct PreprocessorConfig {
pub name: String,
pub message_oriented: bool,
pub config: Value,
}Expand description
Configuration for describing a preprocessor
Fields
name: StringName of the preprocessor. All preprocessors with the same name will perform the same task.
message_oriented: boolTrue if the preprocessor is message-oriented: true if each preprocessor output record corresponds to a whole number of of parser records.
config: ValueArbitrary additional configuration.