Module program_schema

Module program_schema 

Structs

ColumnType
A SQL column type description.
Field
A SQL field.
ProgramSchema
A struct containing the tables (inputs) and views for a program.
ProgramSchemaPropertiesOnly
A version of ProgramSchema that contains only the name and properties of the relations by making use of RelationPropertiesOnly instead of Relation for its inputs and outputs. This is used to avoid parsing the entire Relation object, including SQL schema, which can change across runtime versions.
PropertyValue
Relation
A SQL table or view. It has a name and a list of fields.
RelationPropertiesOnly
A version of Relation that only contains the name and properties. This is used to avoid parsing the entire Relation object, including SQL schema, which can change across runtime versions.
SourcePosition
SqlIdentifier
An SQL identifier.

Enums

IntervalUnit
The specified units for SQL Interval types.
SqlType
The available SQL types as specified in CREATE statements.

Functions

canonical_identifier
Returns canonical form of a SQL identifier: