pub struct RelationPropertiesOnly {
pub name: SqlIdentifier,
pub properties: BTreeMap<String, PropertyValue>,
}Expand description
A version of Relation that only contains the name and properties.
This is used to avoid parsing the entire Relation object, including
SQL schema, which can change across runtime versions.
Fields
name: SqlIdentifierproperties: BTreeMap<String, PropertyValue>Trait Implementations
Sourceimpl Debug for RelationPropertiesOnly
impl Debug for RelationPropertiesOnly
Sourceimpl<'de> Deserialize<'de> for RelationPropertiesOnly
impl<'de> Deserialize<'de> for RelationPropertiesOnly
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more