pub struct SamplyProfileGetParams {
pub ordinal: usize,
pub latest: bool,
}Expand description
Query parameters to retrieve samply profile.
Fields
ordinal: usizeIn a multihost pipeline, the ordinal of the pipeline to sample.
latest: boolIf true, returns 204 redirect with Retry-After header if profile collection is in progress. If false or not provided, returns the last collected profile.