pub struct SamplyProfileParams {
pub ordinal: usize,
pub duration_secs: u64,
}Fields
ordinal: usizeIn a multihost pipeline, the ordinal of the pipeline to sample.
duration_secs: u64The number of seconds to sample for the profile.