ExtendedRuntimeStatus

Struct ExtendedRuntimeStatus 

pub struct ExtendedRuntimeStatus {
    pub runtime_status: RuntimeStatus,
    pub runtime_status_details: Value,
    pub runtime_desired_status: RuntimeDesiredStatus,
    pub storage_status_details: Option<StorageStatusDetails>,
}

Fields

runtime_status: RuntimeStatus

Runtime status of the pipeline.

runtime_status_details: Value

Human-readable details about the runtime status. Its content can contain for instance an explanation why it is in this status and any other additional information about it (e.g., progress).

runtime_desired_status: RuntimeDesiredStatus

Runtime desired status of the pipeline.

storage_status_details: Option<StorageStatusDetails>

Details about the pipeline persistent storage.

None indicates that the pipeline in its current runtime status is unable to check the storage status details. Returning None does not override the already existing storage status details in the database of the runner.