pub struct StorageStatusDetails {
pub checkpoints: VecDeque<CheckpointMetadata>,
}Expand description
Details about pipeline storage, which are returned as part of the regular runtime status polling by the runner.
Fields
checkpoints: VecDeque<CheckpointMetadata>Present checkpoints.