pub struct SuspendableResponse {
pub suspendable: bool,
pub reasons: Vec<PermanentSuspendError>,
}Expand description
Response to a /suspendable request.
Reports whether the pipeline supports suspend and resume operations. If not, provides the reasons why suspending is not supported.
Fields
suspendable: boolIs the pipeline suspendable?
reasons: Vec<PermanentSuspendError>If the pipeline is not suspendable, why not?
Implementations
Sourceimpl SuspendableResponse
impl SuspendableResponse
Sourcepub fn new(suspendable: bool, reasons: Vec<PermanentSuspendError>) -> Self
pub fn new(suspendable: bool, reasons: Vec<PermanentSuspendError>) -> Self
Create a new suspendable response.