#[repr(u8)]pub enum ConcurrentBootstrapPhase {
Inactive = 0,
ConcurrentBootstrapping = 1,
Synchronizing = 2,
}Expand description
Phase of a concurrent bootstrap.
#[repr(u8)] + NoUninit so it can be stored in a lock-free Atomic.
Variants
Inactive = 0
No concurrent bootstrap is in progress.
ConcurrentBootstrapping = 1
New and modified views are backfilling in the background while the pre-existing views stay live and serving.
Synchronizing = 2
The cutover window: inputs are paused while recorded changes are synchronized into the new views.