pub struct CommitProgressSummary {
pub completed: u64,
pub in_progress: u64,
pub remaining: u64,
pub in_progress_processed_records: u64,
pub in_progress_total_records: u64,
}Expand description
Summary of transaction commit progress.
Fields
completed: u64Number of operators that have been fully flushed.
in_progress: u64Number of operators that are currently being flushed.
remaining: u64Number of operators that haven’t started flushing.
in_progress_processed_records: u64Number of records processed by operators that are currently being flushed.
in_progress_total_records: u64Total number of records that operators that are currently being flushed need to process.
Implementations
Sourceimpl CommitProgressSummary
impl CommitProgressSummary
pub fn new() -> Self
pub fn merge(&mut self, other: &CommitProgressSummary)