pub struct PostgresTlsConfig {
pub ssl_ca_pem: Option<String>,
pub ssl_ca_location: Option<String>,
pub ssl_client_pem: Option<String>,
pub ssl_client_location: Option<String>,
pub ssl_client_key: Option<String>,
pub ssl_client_key_location: Option<String>,
pub ssl_certificate_chain_location: Option<String>,
pub verify_hostname: Option<bool>,
}Expand description
TLS/SSL configuration for PostgreSQL connectors.
Fields
ssl_ca_pem: Option<String>A sequence of CA certificates in PEM format.
ssl_ca_location: Option<String>Path to a file containing a sequence of CA certificates in PEM format.
ssl_client_pem: Option<String>The client certificate in PEM format.
ssl_client_location: Option<String>Path to the client certificate.
ssl_client_key: Option<String>The client certificate key in PEM format.
ssl_client_key_location: Option<String>Path to the client certificate key.
ssl_certificate_chain_location: Option<String>The path to the certificate chain file. The file must contain a sequence of PEM-formatted certificates, the first being the leaf certificate, and the remainder forming the chain of certificates up to and including the trusted root certificate.
verify_hostname: Option<bool>True to enable hostname verification when using TLS. True by default.
Implementations