pub struct PostgresWriterConfig {
pub uri: String,
pub table: String,
pub mode: PostgresWriteMode,
pub cdc_op_column: String,
pub cdc_ts_column: String,
pub tls: PostgresTlsConfig,
pub max_records_in_buffer: Option<usize>,
pub max_buffer_size_bytes: usize,
pub on_conflict_do_nothing: bool,
pub threads: usize,
}Expand description
Postgres output connector configuration.
Fields
uri: Stringtable: StringThe table to write the output to.
mode: PostgresWriteModeWrite mode for the connector.
materialized(default): Perform direct INSERT, UPDATE, and DELETE operations on the table.cdc: Write all operations as INSERT operations into an append-only event log with additional metadata columns describing the operation type and timestamp.
cdc_op_column: StringName of the operation metadata column in CDC mode.
Only used when mode = "cdc". This column will contain:
"i"for insert operations"u"for upsert operations"d"for delete operations
Default: "__feldera_op"
cdc_ts_column: StringName of the timestamp metadata column in CDC mode.
Only used when mode = "cdc". This column will contain the timestamp
(in RFC 3339 format) when the batch of updates was output
by the pipeline.
Default: "__feldera_ts"
tls: PostgresTlsConfigTLS/SSL configuration.
max_records_in_buffer: Option<usize>The maximum number of records in a single buffer.
max_buffer_size_bytes: usizeThe maximum buffer size in for a single operation.
Note that the buffers of INSERT, UPDATE and DELETE queries are
separate.
Default: 1 MiB
on_conflict_do_nothing: boolSpecifies how the connector handles conflicts when executing an INSERT
into a table with a primary key. By default, an existing row with the same
key is overwritten. Setting this flag to true preserves the existing row
and ignores the new insert.
This setting does not affect UPDATE statements, which always replace the
value associated with the key.
This setting is not supported when mode = "cdc", since all operations
are performed as append-only INSERTs into the target table.
Any conflict in CDC mode will result in an error.
Default: false
threads: usizeThe number of threads to use during encoding.
Default: 1
Implementations