pub struct CompletionStatusResponse {
pub status: CompletionStatus,
pub step: Option<Step>,
}Expand description
Response to a completion token status request.
Fields
status: CompletionStatusCompletion token status.
step: Option<Step>If all of the data associated with the token has been processed through
the pipeline, this is the final step that includes at least one record.
When the pipeline’s total_completed_steps reaches this value, the
token has been completed.
This is None before the data associated with the token has been
processed through the pipeline.
Implementations