Module pipeline_diff
feldera_
types
0.250.0
Module pipeline_
diff
Module Items
Structs
Functions
In crate feldera_
types
feldera_types
Module
pipeline_
diff
Structs

Pipeline
Diff
Summary of changes in the pipeline between checkpointed and new versions.
Program
Diff
Summary of changes in the program between checkpointed and new versions.
Functions

program_
diff