A version of ProgramSchema that contains only the name and properties of the relations
by making use of RelationPropertiesOnly instead of Relation for its inputs and outputs.
This is used to avoid parsing the entire Relation object, including SQL schema,
which can change across runtime versions.
A version of Relation that only contains the name and properties.
This is used to avoid parsing the entire Relation object, including
SQL schema, which can change across runtime versions.