pub struct ProgramSchemaPropertiesOnly {
pub inputs: Vec<RelationPropertiesOnly>,
pub outputs: Vec<RelationPropertiesOnly>,
}Expand description
A version of ProgramSchema that contains only the name and properties of the relations
by making use of RelationPropertiesOnly instead of Relation for its inputs and outputs.
This is used to avoid parsing the entire Relation object, including SQL schema,
which can change across runtime versions.
Fields
inputs: Vec<RelationPropertiesOnly>outputs: Vec<RelationPropertiesOnly>Trait Implementations
Sourceimpl Debug for ProgramSchemaPropertiesOnly
impl Debug for ProgramSchemaPropertiesOnly
Sourceimpl<'de> Deserialize<'de> for ProgramSchemaPropertiesOnly
impl<'de> Deserialize<'de> for ProgramSchemaPropertiesOnly
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more