RelationPropertiesOnly

Struct RelationPropertiesOnly 

pub struct RelationPropertiesOnly {
    pub name: SqlIdentifier,
    pub properties: BTreeMap<String, PropertyValue>,
}
A version of Relation that only contains the name and properties. This is used to avoid parsing the entire Relation object, including SQL schema, which can change across runtime versions.

Fields

name: SqlIdentifierproperties: BTreeMap<String, PropertyValue>